@@ -36,13 +36,21 @@ import freak.core.util.GraphViz;
 import freak.gui.graph.OperatorGraphFile;
 import freak.gui.scheduleeditor.ScheduleDependencyChecker;
 import freak.module.fitness.booleanfunction.GenericPareto;
+import freak.module.fitness.pointset.LMSOptimization;
+import freak.module.fitness.pointset.LQDOptimization;
+import freak.module.fitness.pointset.LQSOptimization;
+import freak.module.fitness.pointset.LTAOptimization;
 import freak.module.fitness.pointset.LtSOptimization;
+import freak.module.fitness.pointset.LtSParetoOptimization;
+import freak.module.fitness.pointset.LtSParetoQuantileOptimization;
 import freak.module.observer.ResultObserver;
 import freak.module.operator.initialization.LTSInitialization;
 import freak.module.postprocessor.booleanfunction.Count;
 import freak.module.searchspace.BooleanFunction;
 import freak.module.searchspace.PointSet;
+import freak.module.stoppingcriterion.Duration;
 import freak.module.stoppingcriterion.GenerationCount;
+import freak.module.stoppingcriterion.PredictingModelFound;
 
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -56,6 +64,7 @@ import java.security.CodeSource;
  */
 public class ScheduleConfigurator {
 	
+//	public static String[] regressionMethods={"lms","lqd","lqs","lta","lts"};
 	static Schedule currentSchedule;
 	
 	static boolean editingFinished = false;
@@ -86,13 +95,40 @@ public class ScheduleConfigurator {
 	
 	// called from R
 	public static void setDiscriminationR(int runs,int generations) {
-		setDiscrimination("ignored",runs,generations,"ignored","");
+		setDiscriminationR(runs,generations,12);
 	}
 	
-	// called from "Qucik Start GPAS"
+	public static void setDiscriminationR(int runs,int generations,String graphFile) {
+		setDiscriminationR(runs,generations,12,false,graphFile);
+	}
+	
+	public static void setDiscriminationR(int runs,int generations,int sizePruning) {
+		setDiscriminationR(runs,generations,sizePruning,false);
+	}
+
+	public static void setDiscriminationR(int runs,int generations,int sizePruning,boolean stoppingCriterion) {
+		setDiscriminationR(runs,generations,sizePruning,stoppingCriterion,"GPASGraph.fop");
+	}
+	
+	public static void setDiscriminationR(int runs,int generations,int sizePruning,boolean stoppingCriterion,String graphFile) {
+		setDiscrimination("ignored",runs,generations,"ignored","",sizePruning,stoppingCriterion,graphFile);
+	}
+
+	// called from "Quick Start GPAS"
 	public static void setDiscrimination(String path,int runs,int generations, String testDataPath,String saveTo) {
-		createSchedule(path,runs,generations);
-		//.jcall("freak/rinterface/model/ScheduleConfigurator","Lfreak/core/control/Schedule;","createSchedule", "ignored",runsJava,generationJava,"ignored");
+		setDiscrimination(path,runs,generations,testDataPath,saveTo,12);
+	}
+
+	public static void setDiscrimination(String path,int runs,int generations, String testDataPath,String saveTo,int sizePruning) {
+		setDiscrimination(path,runs,generations,testDataPath,saveTo,sizePruning,false);
+	}
+	
+	public static void setDiscrimination(String path,int runs,int generations, String testDataPath,String saveTo,int sizePruning,boolean stoppingCriterion) {
+		setDiscrimination(path,runs,generations,testDataPath,saveTo,sizePruning,false,"GPASGraph.fop");
+	}
+	
+	public static void setDiscrimination(String path,int runs,int generations, String testDataPath,String saveTo,int sizePruning,boolean stoppingCriterion,String graphFile) {
+		createSchedule(path,runs,generations,stoppingCriterion,graphFile);
 		Module m;
 		try {
 			currentSchedule.setFitnessFunction(null);
@@ -100,7 +136,7 @@ public class ScheduleConfigurator {
 			m = new GenericPareto(currentSchedule);
 			((GenericPareto)m).setParetoObjective(new int[] {GenericPareto.OBJECTIVE_CASES,GenericPareto.OBJECTIVE_CONTROLS,GenericPareto.OBJECTIVE_LENGTH});
 			((GenericPareto)m).setPropertySubsets(new Integer(1));
-			((GenericPareto)m).setPropertySizePruning(new Integer(12));
+			((GenericPareto)m).setPropertySizePruning(new Integer(sizePruning));
 			m.testSchedule(currentSchedule);
 			m.initialize();
 			m.createEvents();
@@ -140,6 +176,51 @@ public class ScheduleConfigurator {
 		updateBatchForSchedule(currentSchedule,runs);
 	}
 	
+
+	public static void setGeccoFitnessFunction(int fitnessfunction) {
+		setGeccoFitnessFunction(fitnessfunction,12);
+	}
+
+	public static void setGeccoFitnessFunction(int fitnessfunction,int sizePruning) {
+		Module m;
+		try {
+			currentSchedule.setFitnessFunction(null);
+			// Fitnessfunktion
+			m = new GenericPareto(currentSchedule);
+			switch (fitnessfunction) 
+			{
+				case 1: 
+				{
+					((GenericPareto)m).setParetoObjective(new int[] {GenericPareto.OBJECTIVE_STANDARDISED_FITNESS_LENGTH,GenericPareto.OBJECTIVE_STANDARDISED_FITNESS_LENGTH,GenericPareto.OBJECTIVE_NONE});		
+					break;
+				}
+				case 2: 
+				{
+					((GenericPareto)m).setParetoObjective(new int[] {GenericPareto.OBJECTIVE_STANDARDISED_FITNESS_IMPLICIT_LENGTH,GenericPareto.OBJECTIVE_STANDARDISED_FITNESS_IMPLICIT_LENGTH,GenericPareto.OBJECTIVE_NONE});		
+					break;
+				}
+				case 3: 
+				{
+					((GenericPareto)m).setParetoObjective(new int[] {GenericPareto.OBJECTIVE_STANDARDISED_FITNESS,GenericPareto.OBJECTIVE_LENGTH,GenericPareto.OBJECTIVE_NONE});		
+					break;
+				}
+				case 4: 
+				{
+					((GenericPareto)m).setParetoObjective(new int[] {GenericPareto.OBJECTIVE_CASES,GenericPareto.OBJECTIVE_CONTROLS,GenericPareto.OBJECTIVE_LENGTH});		
+					break;
+				}
+			}
+			((GenericPareto)m).setPropertySubsets(new Integer(1));
+			((GenericPareto)m).setPropertySizePruning(new Integer(sizePruning));
+			m.testSchedule(currentSchedule);
+			m.initialize();
+			m.createEvents();
+			currentSchedule.setFitnessFunction((FitnessFunction)m);
+		} catch (UnsupportedEnvironmentException e) {
+			throw new RuntimeException("Something is wrong with the default Schedule.", e);
+		}				
+	}
+	
 	// called from R
 	public static void setInteractionR(int runs,int generations,String graphFile,int occurences,double ratio) {
 		setInteraction("ignored",runs,generations,graphFile,occurences,ratio,"");
@@ -205,8 +286,6 @@ public class ScheduleConfigurator {
 	}
 			
 	public static void setGenerationCount(int gencount) {
-		//RJava macht Probleme bei ints, deswegen Workaround mittels String-Parsing
-//		int gencount = Integer.parseInt(gc);
 		try {
 			GenerationCount generationCount = new GenerationCount(currentSchedule);
 			generationCount.setPropertyCount(new Integer(gencount));
@@ -270,6 +349,20 @@ public class ScheduleConfigurator {
 	}
 	
 	public static Schedule getLTSSchedule(RDoubleMatrix data,int h,boolean adjust,int runs,int generationCountStop) {
+		return getLTSSchedule(data, h,adjust,runs,generationCountStop,0,0);
+	}
+
+
+	public static Schedule getLTSSchedule(RDoubleMatrix data,int h,boolean adjust,int runs,int generationCountStop,int duration,String fitnessFunction) {
+		int function=0;
+		if (fitnessFunction.equals("lts")) function=0;
+		if (fitnessFunction.equals("lms")) function=1;
+		if (fitnessFunction.equals("lta")) function=6;
+		if (fitnessFunction.equals("lqs")) function=7;
+		if (fitnessFunction.equals("lqd")) function=8;
+		return getLTSSchedule(data, h,adjust,runs,generationCountStop,duration,function);
+	}
+	public static Schedule getLTSSchedule(RDoubleMatrix data,int h,boolean adjust,int runs,int generationCountStop,int duration,int fitnessFunction) {
 		Schedule schedule = new Schedule();
 		
 		ScheduleDependencyChecker scheduleDependencyChecker = new ScheduleDependencyChecker(null);
@@ -295,9 +388,54 @@ public class ScheduleConfigurator {
 			schedule.setPhenotypeSearchSpace((SearchSpace)m);
 
 			// Fitnessfunktion
-			m = new freak.module.fitness.pointset.LtSOptimization(schedule);
-			((LtSOptimization)m).setPropertyH(new Integer(h));
-			((LtSOptimization)m).setPropertyAdjust(adjust);
+			switch(fitnessFunction) {
+				case 0: 
+					m = new freak.module.fitness.pointset.LtSOptimization(schedule);
+					((LtSOptimization)m).setPropertyH(new Integer(h));
+					((LtSOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 1:
+					m = new freak.module.fitness.pointset.LMSOptimization(schedule);
+					((LMSOptimization)m).setPropertyH(new Integer(h));
+					((LMSOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 2:
+					m = new freak.module.fitness.pointset.LtSParetoQuantileOptimization(schedule);
+					((LtSParetoQuantileOptimization)m).setPropertyH(new Integer(h));
+					((LtSParetoQuantileOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 3:
+					m = new freak.module.fitness.pointset.LtSParetoOptimization(schedule);
+					((LtSParetoOptimization)m).setPropertyH(new Integer(h));
+					((LtSParetoOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 4:
+					m = new freak.module.fitness.pointset.LtSParetoQuantileOptimization(schedule);
+					((LtSParetoQuantileOptimization)m).setPropertyH(new Integer(h));
+					((LtSParetoQuantileOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 5:
+					m = new freak.module.fitness.pointset.LtSParetoOptimization(schedule);
+					((LtSParetoOptimization)m).setPropertyH(new Integer(h));
+					((LtSParetoOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 6:
+					m = new freak.module.fitness.pointset.LTAOptimization(schedule);
+					((LTAOptimization)m).setPropertyH(new Integer(h));
+					((LTAOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 7:
+					m = new freak.module.fitness.pointset.LQSOptimization(schedule);
+					((LQSOptimization)m).setPropertyH(new Integer(h));
+//					((LQSOptimization)m).setPropertyAdjust(adjust);
+					break;
+				case 8:
+					m = new freak.module.fitness.pointset.LQDOptimization(schedule);
+					((LQDOptimization)m).setPropertyH(new Integer(h));
+//					((LQDOptimization)m).setPropertyAdjust(adjust);					
+					break;
+
+			}
 			m.testSchedule(schedule);
 			m.initialize();
 			m.createEvents();
@@ -322,6 +460,17 @@ public class ScheduleConfigurator {
 				schedule.setStoppingCriteria(stoppingCriteria);
 			}
 
+			if (duration>0) {
+				Duration durationObject = new Duration(schedule);
+				durationObject.setPropertyDuration(new Integer(duration));
+				durationObject.testSchedule(schedule);
+				durationObject.initialize();
+				durationObject.createEvents();
+		
+				StoppingCriterion[] stoppingCriteria = {durationObject};
+				schedule.setStoppingCriteria(stoppingCriteria);
+			}
+
 			// Populationmanager
 			m = new freak.module.populationmanager.DefaultPopulationManager(schedule);
 			m.testSchedule(schedule);
@@ -331,8 +480,15 @@ public class ScheduleConfigurator {
 			
 			// Operatorgraph
 			OperatorGraphCollector collector=new OperatorGraphCollector(schedule);
-				      	      
-			ModuleInfo[] graphs = collector.getPredefinedGraphs("LTSGraph.fop");
+			
+			ModuleInfo[] graphs=null;
+			if ((fitnessFunction<=1)||(fitnessFunction>5)) {
+				graphs = collector.getPredefinedGraphs("LTSGraph.fop");
+			} else if (fitnessFunction<=3) {
+				graphs = collector.getPredefinedGraphs("LTSCrossover.fop");
+			} else if (fitnessFunction<=5) {
+				graphs = collector.getPredefinedGraphs("LTSCrossMove.fop");				
+			}
 			if (graphs != null) {
 				try {
 					OperatorGraphFile ogFile;
@@ -386,10 +542,19 @@ public class ScheduleConfigurator {
 	}
 		
 	//ScheduleConfigurator.createSchedule(jTextField.getText(),runs,generations,"./export/resource/freak/module/graph/booleanfunction/ZuFaulZumKlicken.fop");
-	
+
 	// USED FROM THE GPAS QUICK START GUI
 	//creates the same schedule as the method createSchedule in class LogRegInterface		
-	public static Schedule createSchedule(String path,int runs,int generationCountStop) {//,String graphPath) {
+
+	public static Schedule createSchedule(String path,int runs,int generationCountStop) {
+		return createSchedule(path,runs,generationCountStop,false);
+	}
+
+	public static Schedule createSchedule(String path,int runs,int generationCountStop,boolean stoppingCriterion) {
+		return createSchedule(path,runs,generationCountStop,false,"GPASGraph.fop");
+	}
+	
+	public static Schedule createSchedule(String path,int runs,int generationCountStop,boolean stoppingCriterion,String graphFile) {
 
 		Schedule schedule = new Schedule();
 		
@@ -414,14 +579,30 @@ public class ScheduleConfigurator {
 			schedule.setFitnessFunction((FitnessFunction)m);
 
 			// Stoppkriterium
-			if (generationCountStop>0) {
+			if ((generationCountStop>0)||(stoppingCriterion)) {
 				GenerationCount generationCount = new GenerationCount(schedule);
 				generationCount.setPropertyCount(new Integer(generationCountStop));
 				generationCount.testSchedule(schedule);
 				generationCount.initialize();
 				generationCount.createEvents();
+				
+				PredictingModelFound predictionFound = new PredictingModelFound(schedule);
+				predictionFound.testSchedule(schedule);
+				predictionFound.initialize();
+				predictionFound.createEvents();
 		
-				StoppingCriterion[] stoppingCriteria = {generationCount};
+				StoppingCriterion[] stoppingCriteria = null;
+				if ((generationCountStop>0)&&(stoppingCriterion)) {
+					stoppingCriteria = new StoppingCriterion[2];
+					stoppingCriteria[0] = generationCount;	
+					stoppingCriteria[1] = predictionFound;	
+				} else if(generationCountStop>0) {
+					stoppingCriteria = new StoppingCriterion[1];
+					stoppingCriteria[0] = generationCount;						
+				} else {
+					stoppingCriteria = new StoppingCriterion[1];
+					stoppingCriteria[0] = predictionFound;											
+				}				
 				schedule.setStoppingCriteria(stoppingCriteria);
 			}
 			// Populationmanager
@@ -434,7 +615,7 @@ public class ScheduleConfigurator {
 			// Operatorgraph
 			OperatorGraphCollector collector=new OperatorGraphCollector(schedule);
 				      	      
-			ModuleInfo[] graphs = collector.getPredefinedGraphs("GPASGraph.fop");
+			ModuleInfo[] graphs = collector.getPredefinedGraphs(graphFile);
 			if (graphs != null) {
 				try {
 					OperatorGraphFile ogFile;
